==> vue-slider-button-group-2.8.0.tgz: package/lib/mobile-first.js <==
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
import { renderless as renderless$1, api as api$1 } from "@dftvue2-opentiny/vue-renderless/slider-button-group/vue";
import { defineComponent, $props, setup as _setup, props } from "@dftvue2-opentiny/vue-common";
import SliderButton from "@dftvue2-opentiny/vue-slider-button";
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/slider-button-group/slide-button";
import { IconChevronRight, IconChevronLeft } from "@dftvue2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script$1 = defineComponent({
  emits: ["click"],
  components: {
    IconChevronRight: IconChevronRight(),
    IconChevronLeft: IconChevronLeft()
  },
  props: _extends({}, $props, {
    noArrow: Boolean,
    flex: Boolean,
    size: String,
    sliderSpace: Number,
    sliderWidth: Number,
    delay: {
      type: Number,
      default: 5
    },
    sliderHeight: Number,
    data: Array,
    duration: {
      type: Number,
      default: 300
    },
    sliderCount: {
      type: Number,
      default: 0
    },
    currentIndex: {
      type: Number,
      default: 0
    }
  }),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render$1 = function render$12() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "items-center w-full flex",
    attrs: {
      "data-tag": "tiny-slider-button-bar"
    }
  }, [_c("div", {
    class: ["hidden flex-none h-12 items-center select-none cursor-pointer bg-color-bg-1", {
      "sm:flex": _vm.sliderState.canLeftScroll || _vm.sliderState.canRightScroll
    }],
    on: {
      "click": _vm.arrowLeftHandler
    }
  }, [_vm._t("left-bar", function() {
    return [_c("div", {
      staticClass: "w-7 flex items-center justify-center h-full pr-2"
    }, [_c("IconChevronLeft", {
      class: ["h-5 w-5", _vm.sliderState.canLeftScroll ? "fill-color-icon-primary" : "fill-color-text-disabled"]
    })], 1)];
  }, {
    "dataTag": "tiny-slider-button-bar-left"
  })], 2), _c("div", {
    ref: "slideMain",
    class: ["inline-flex rounded relative scrollbar-size-0 box-border flex-auto overflow-auto", _vm.size === "large" ? "h-auto" : _vm.size === "medium" ? "h-8" : "h-7"]
  }, [_c("div", {
    class: ["absolute bg-color-bg-1 shadow h-6 rounded", _vm.size === "large" ? "top-1" : "top-0.5"],
    style: {
      "transition": "left 0.5s",
      "left": _vm.sliderSpace + "px",
      "width": _vm.sliderWidth + "px",
      "height": _vm.sliderHeight + "px"
    }
  }), _c("div", {
    staticClass: "flex bg-color-bg-2 rounded-md"
  }, _vm._l(_vm.data, function(node, index) {
    return _c("div", {
      key: index,
      ref: "block" + index,
      refInFor: true,
      style: {
        width: _vm.flex ? 100 / _vm.data.length + "%" : null
      },
      on: {
        "click": function click($event) {
          return _vm.clickHandler(index);
        }
      }
    }, [_vm._t("content", null, {
      "dataTag": "tiny-slider-button-bar-content",
      "slotScoped": {
        node,
        index,
        show: index > _vm.sliderState.boundingIndex.left && (_vm.sliderState.boundingIndex.right === -1 || index < _vm.sliderState.boundingIndex.right)
      }
    })], 2);
  }), 0)]), _c("div", {
    class: ["hidden flex-none h-12 cursor-pointer items-center select-none bg-color-bg-1", {
      "sm:flex": _vm.sliderState.canLeftScroll || _vm.sliderState.canRightScroll
    }],
    on: {
      "click": _vm.arrowRightHandler
    }
  }, [_vm._t("right-bar", function() {
    return [_c("div", {
      staticClass: "w-7 h-full flex items-center justify-center pl-2"
    }, [_c("IconChevronRight", {
      class: ["h-5 w-5", _vm.sliderState.canRightScroll ? "fill-color-icon-primary" : "fill-color-text-disabled"]
    })], 1)];
  }, {
    "dataTag": "tiny-slider-button-bar-right"
  })], 2)]);
};
var staticRenderFns$1 = [];
var __cssModules$1 = {};
var __component__$1 = /* @__PURE__ */ normalizeComponent(__vue2_script$1, render$1, staticRenderFns$1, false, __vue2_injectStyles$1, null, null, null);
function __vue2_injectStyles$1(context) {
  for (var o in __cssModules$1) {
    this[o] = __cssModules$1[o];
  }
}
var SlideBar = /* @__PURE__ */ function() {
  return __component__$1.exports;
}();
var __vue2_script = defineComponent({
  components: {
    SliderButton,
    SlideBar
  },
  emits: ["change"],
  props: [].concat(props, ["options", "modelValue", "type", "size", "pageTurn", "duration", "nameField", "iconField", "noArrow", "flex", "delay"]),
  setup: function setup2(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless: renderless$1,
      api: api$1
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    attrs: {
      "data-tag": "tiny-slider-button-group"
    }
  }, [!_vm.pageTurn ? _c(_vm.state.tag, {
    tag: "component",
    staticClass: "inline-flex",
    attrs: {
      "role": "sliderButtonGroup"
    }
  }, [_c("div", {
    staticClass: "bg-color-bg-2 inline-flex h-auto rounded-md relative box-border"
  }, [_c("div", {
    class: ["absolute bg-color-bg-1 shadow h-6 rounded", _vm.size === "large" ? "top-1" : "top-0.5"],
    style: {
      "transition": "left 0.5s",
      "left": _vm.state.sliderSpace + "px",
      "width": _vm.state.sliderWidth + "px",
      "height": _vm.state.sliderHeight + "px"
    }
  }), _vm.options && _vm.options.length !== 0 ? _vm._t("default", function() {
    return _vm._l(_vm.options, function(item, index) {
      return _c("slider-button", _vm._b({
        key: index
      }, "slider-button", item, false));
    });
  }) : _vm._t("default")], 2)]) : _c(_vm.state.tag, {
    tag: "component",
    staticClass: "flex",
    attrs: {
      "role": "sliderButtonGroup"
    }
  }, [_c("SlideBar", {
    ref: "slideBar",
    attrs: {
      "data": _vm.options,
      "duration": _vm.duration,
      "no-arrow": _vm.noArrow,
      "flex": _vm.flex,
      "size": _vm.size,
      "slider-space": _vm.state.sliderSpace,
      "slider-width": _vm.state.sliderWidth,
      "slider-height": _vm.state.sliderHeight,
      "type": _vm.type,
      "sliderCount": _vm.state.sliderCount,
      "currentIndex": _vm.state.currentIndex,
      "delay": _vm.delay
    },
    scopedSlots: _vm._u([{
      key: "left-bar",
      fn: function fn() {
        return void 0;
      },
      proxy: true
    }, {
      key: "right-bar",
      fn: function fn() {
        return void 0;
      },
      proxy: true
    }, _vm.options && _vm.options.length !== 0 ? {
      key: "content",
      fn: function fn(_ref) {
        var _ref$slotScoped = _ref.slotScoped, node = _ref$slotScoped.node, index = _ref$slotScoped.index;
        return [_vm.type !== "icon" ? _vm._t("item", function() {
          return [_c("slider-button", _vm._b({
            attrs: {
              "label": node[_vm.nameField]
            }
          }, "slider-button", node, false))];
        }, {
          "slotScope": node,
          "index": index
        }) : _vm._t("default", function() {
          return [_c("slider-button", _vm._b({}, "slider-button", node, false), [_c(node[_vm.iconField], {
            tag: "component"
          })], 1)];
        }, {
          "index": index
        })];
      }
    } : null], null, true)
  })], 1)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobileFirst as default
};

==> vue-slider-button-group-2.22.0.tgz: package/lib/mobile-first.js <==
import { renderless as renderless$1, api as api$1 } from '@opentinyvue/vue-renderless/slider-button-group/vue';
import { defineComponent, setup, props, $props } from '@opentinyvue/vue-common';
import SliderButton from '@opentinyvue/vue-slider-button';
import { renderless, api } from '@opentinyvue/vue-renderless/slider-button-group/slide-button';
import { iconChevronRight, iconChevronLeft } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t) ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
var __vue2_script$1 = defineComponent({
  emits: ["click"],
  components: {
    IconChevronRight: iconChevronRight(),
    IconChevronLeft: iconChevronLeft()
  },
  props: _extends({}, $props, {
    noArrow: Boolean,
    flex: Boolean,
    size: String,
    sliderSpace: Number,
    sliderWidth: Number,
    delay: {
      type: Number,
      default: 5
    },
    sliderHeight: Number,
    data: Array,
    duration: {
      type: Number,
      default: 300
    },
    sliderCount: {
      type: Number,
      default: 0
    },
    currentIndex: {
      type: Number,
      default: 0
    }
  }),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render$1 = function render$12() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "items-center w-full flex",
    attrs: {
      "data-tag": "tiny-slider-button-bar"
    }
  }, [_c("div", {
    class: ["hidden flex-none h-12 items-center select-none cursor-pointer bg-color-bg-1", {
      "sm:flex": _vm.sliderState.canLeftScroll || _vm.sliderState.canRightScroll
    }],
    on: {
      "click": _vm.arrowLeftHandler
    }
  }, [_vm._t("left-bar", function() {
    return [_c("div", {
      staticClass: "w-7 flex items-center justify-center h-full pr-2"
    }, [_c("IconChevronLeft", {
      class: ["h-5 w-5", _vm.sliderState.canLeftScroll ? "fill-color-icon-primary" : "fill-color-text-disabled"]
    })], 1)];
  }, {
    "dataTag": "tiny-slider-button-bar-left"
  })], 2), _c("div", {
    ref: "slideMain",
    class: ["inline-flex rounded relative scrollbar-size-0 box-border flex-auto overflow-auto", _vm.size === "large" ? "h-auto" : _vm.size === "medium" ? "h-8" : "h-7"]
  }, [_c("div", {
    class: ["absolute bg-color-bg-1 shadow h-6 rounded", _vm.size === "large" ? "top-1" : "top-0.5"],
    style: {
      "transition": "left 0.5s",
      "left": _vm.sliderSpace + "px",
      "width": _vm.sliderWidth + "px",
      "height": _vm.sliderHeight + "px"
    }
  }), _c("div", {
    staticClass: "flex bg-color-bg-2 rounded-md"
  }, _vm._l(_vm.data, function(node, index) {
    return _c("div", {
      key: index,
      ref: "block" + index,
      refInFor: true,
      style: {
        width: _vm.flex ? 100 / _vm.data.length + "%" : null
      },
      on: {
        "click": function click($event) {
          return _vm.clickHandler(index);
        }
      }
    }, [_vm._t("content", null, {
      "dataTag": "tiny-slider-button-bar-content",
      "slotScoped": {
        node,
        index,
        show: index > _vm.sliderState.boundingIndex.left && (_vm.sliderState.boundingIndex.right === -1 || index < _vm.sliderState.boundingIndex.right)
      }
    })], 2);
  }), 0)]), _c("div", {
    class: ["hidden flex-none h-12 cursor-pointer items-center select-none bg-color-bg-1", {
      "sm:flex": _vm.sliderState.canLeftScroll || _vm.sliderState.canRightScroll
    }],
    on: {
      "click": _vm.arrowRightHandler
    }
  }, [_vm._t("right-bar", function() {
    return [_c("div", {
      staticClass: "w-7 h-full flex items-center justify-center pl-2"
    }, [_c("IconChevronRight", {
      class: ["h-5 w-5", _vm.sliderState.canRightScroll ? "fill-color-icon-primary" : "fill-color-text-disabled"]
    })], 1)];
  }, {
    "dataTag": "tiny-slider-button-bar-right"
  })], 2)]);
};
var staticRenderFns$1 = [];
var __cssModules$1 = {};
var __component__$1 = /* @__PURE__ */ normalizeComponent(__vue2_script$1, render$1, staticRenderFns$1, false, __vue2_injectStyles$1);
function __vue2_injectStyles$1(context) {
  for (var o in __cssModules$1) {
    this[o] = __cssModules$1[o];
  }
}
var SlideBar = /* @__PURE__ */ function() {
  return __component__$1.exports;
}();
var __vue2_script = defineComponent({
  components: {
    SliderButton,
    SlideBar
  },
  emits: ["change"],
  props: [].concat(props, ["options", "modelValue", "type", "size", "pageTurn", "duration", "nameField", "iconField", "noArrow", "flex", "delay", "disabled"]),
  setup: function setup2(props2, context) {
    return setup({
      props: props2,
      context,
      renderless: renderless$1,
      api: api$1
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    ref: "sliderButtonGroup",
    attrs: {
      "data-tag": "tiny-slider-button-group"
    }
  }, [!_vm.pageTurn ? _c(_vm.state.tag, {
    tag: "component",
    staticClass: "inline-flex",
    attrs: {
      "role": "sliderButtonGroup"
    }
  }, [_c("div", {
    ref: "sliderButtonBox",
    staticClass: "bg-color-bg-3 inline-flex h-auto rounded-md relative box-border"
  }, [_c("div", {
    class: ["absolute bg-color-bg-1 shadow-sm h-6 rounded", _vm.size === "large" ? "top-1" : "top-0.5"],
    style: {
      "transition": "left 0.25s,width 0.25s",
      "left": _vm.state.sliderSpace + "px",
      "width": _vm.state.sliderWidth + "px",
      "height": _vm.state.sliderHeight + "px"
    }
  }), _vm.options && _vm.options.length !== 0 ? _vm._t("default", function() {
    return _vm._l(_vm.options, function(item, index) {
      return _c("slider-button", _vm._b({
        key: index
      }, "slider-button", item, false));
    });
  }) : _vm._t("default")], 2)]) : _c(_vm.state.tag, {
    tag: "component",
    staticClass: "flex",
    attrs: {
      "role": "sliderButtonGroup"
    }
  }, [_c("SlideBar", {
    ref: "slideBar",
    attrs: {
      "data": _vm.options,
      "duration": _vm.duration,
      "no-arrow": _vm.noArrow,
      "flex": _vm.flex,
      "size": _vm.size,
      "slider-space": _vm.state.sliderSpace,
      "slider-width": _vm.state.sliderWidth,
      "slider-height": _vm.state.sliderHeight,
      "type": _vm.type,
      "sliderCount": _vm.state.sliderCount,
      "currentIndex": _vm.state.currentIndex,
      "delay": _vm.delay
    },
    scopedSlots: _vm._u([{
      key: "left-bar",
      fn: function fn() {
        return void 0;
      },
      proxy: true
    }, {
      key: "right-bar",
      fn: function fn() {
        return void 0;
      },
      proxy: true
    }, _vm.options && _vm.options.length !== 0 ? {
      key: "content",
      fn: function fn(_ref) {
        var _ref$slotScoped = _ref.slotScoped, node = _ref$slotScoped.node, index = _ref$slotScoped.index;
        return [_vm.type !== "icon" ? _vm._t("item", function() {
          return [_c("slider-button", _vm._b({
            attrs: {
              "label": node[_vm.nameField]
            }
          }, "slider-button", node, false))];
        }, {
          "slotScope": node,
          "index": index
        }) : _vm._t("default", function() {
          return [_c("slider-button", _vm._b({}, "slider-button", node, false), [_c(node[_vm.iconField], {
            tag: "component"
          })], 1)];
        }, {
          "index": index
        })];
      }
    } : null], null, true)
  })], 1)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
